@@ -17,7 +17,7 @@
 void F_U0ARGCC( n )
 int *n;
 {
-#if defined( SUNSYSTEM ) || defined( CONVEXSYSTEM ) || defined( LINUXSYSTEM ) || defined( DECSYSTEM )
+#if defined( SUNSYSTEM ) || defined( CONVEXSYSTEM ) || defined( LINUXSYSTEM ) || defined( DECSYSTEM ) || defined ( APPLESYSTEM )
 
 	int iargc_();
 
