@@ -26,8 +26,11 @@
 #include <math.h>
 #include <localsys.h>
 
-#if defined( CRAYSYSTEM )
+#ifdef CRAYSYSTEM
 #include <fortran.h>
+#endif
+
+#if defined( FTN_TO_C_UPPERCASE )
 #define VRECIP VRECIP
 #define DAVG2TAVG DAVG2TAVG
 #define PSMOOTH PSMOOTH
@@ -46,7 +49,7 @@
 #define VELBLOCK VELBLOCK
 #endif
 
-#if defined( SUNSYSTEM ) || defined( LINUXSYSTEM ) || defined( CONVEXSYSTEM ) || defined( SGISYSTEM )
+#if defined( FTN_TO_C_UNDERSCORE_SUFFIX )
 #define VRECIP vrecip_
 #define DAVG2TAVG davg2tavg_
 #define PSMOOTH psmooth_
