@@ -149,10 +149,10 @@ int nt,nz;
     }
 
 /*####################################################################*/
-#ifdef CRAYSYSTEM
+#if defined( FTN_TO_C_UPPERCASE )
 #define LINTERP LINTERP
 #endif
-#if defined( SUNSYSTEM ) || defined ( LINUXSYSTEM) || defined ( CONVEXSYSTEM ) || defined( SGISYSTEM )
+#if defined( FTN_TO_C_UNDERSCORE_SUFFIX )
 #define LINTERP linterp_
 #endif
 
@@ -293,7 +293,7 @@ int ndepth;
 #ifdef CRAYSYSTEM
 #define TLP2TINT TLP2TINT
 #endif
-#if defined( SUNSYSTEM ) || defined ( LINUXSYSTEM) || defined ( CONVEXSYSTEM ) || defined( SGISYSTEM )
+#if defined( FTN_TO_C_UNDERSCORE_SUFFIX )
 #define TLP2TINT tlp2tint_
 #endif
 
@@ -390,10 +390,10 @@ int n;
         }
     }
 /*##############################################################*/
-#ifdef CRAYSYSTEM
+#if defined( FTN_TO_C_UPPERCASE )
 #define NLD2NLT NLD2NLT
 #endif
-#if defined( SUNSYSTEM ) || defined ( LINUXSYSTEM) || defined ( CONVEXSYSTEM ) || defined( SGISYSTEM )
+#if defined( FTN_TO_C_UNDERSCORE_SUFFIX )
 #define NLD2NLT nld2nlt_
 #endif
 
@@ -427,10 +427,10 @@ int ndepth;
         }
     }  
 /*################################################################*/
-#ifdef CRAYSYSTEM
+#if defined( FTN_TO_C_UPPERCASE )
 #define T2NLD T2NLD
 #endif
-#if defined( SUNSYSTEM ) || defined ( LINUXSYSTEM) || defined ( CONVEXSYSTEM ) || defined( SGISYSTEM )
+#if defined( FTN_TO_C_UNDERSCORE_SUFFIX )
 #define T2NLD t2nld_
 #endif
 
@@ -810,10 +810,10 @@ int nt,nsmooth;
 
     }
 /*############################################################*/
-#ifdef CRAYSYSTEM
+#if defined( FTN_TO_C_UPPERCASE )
 #define INFILL INFILL
 #endif
-#if defined( SUNSYSTEM ) || defined ( LINUXSYSTEM) || defined ( CONVEXSYSTEM ) || defined( SGISYSTEM )
+#if defined( FTN_TO_C_UNDERSCORE_SUFFIX )
 #define INFILL infill_
 #endif
 /*############################################################*/
@@ -869,10 +869,10 @@ int n;
 /*  old value is no greater than dv.  When a segment is blocked it is  */
 /*  replaced with the slowness average of the unblocked values. */
 /*####################################################################*/
-#ifdef CRAYSYSTEM
+#if defined( FTN_TO_C_UPPERCASE )
 #define VELBLOCK VELBLOCK
 #endif
-#if defined( SUNSYSTEM ) || defined ( LINUXSYSTEM) || defined ( CONVEXSYSTEM ) || defined( SGISYSTEM )
+#if defined( FTN_TO_C_UNDERSCORE_SUFFIX )
 #define VELBLOCK velblock_
 #endif
 void VELBLOCK(vel,n,dv)
