@@ -30,6 +30,9 @@
 
 #ifdef CRAYSYSTEM
 #include <fortran.h>
+#endif
+
+#if defined( FTN_TO_C_UPPERCASE )
 #define VRECIP VRECIP
 #define DAVG2TAVG DAVG2TAVG
 #define PSMOOTH PSMOOTH
@@ -48,7 +51,7 @@
 #define VELBLOCK VELBLOCK
 #endif
 
-#if defined( SUNSYSTEM ) || defined ( LINUXSYSTEM ) || defined ( CONVEXSYSTEM ) || defined( SGISYSTEM )
+#if defined( FTN_TO_C_UNDERSCORE_SUFFIX )
 #define VRECIP vrecip_
 #define DAVG2TAVG davg2tavg_
 #define PSMOOTH psmooth_
@@ -67,7 +70,7 @@
 #define VELBLOCK velblock_
 #endif
 
-#ifdef HPUXSYSTEM
+#if defined( FTN_TO_C_NAME_COMPATABILITY )
 #define VRECIP vrecip
 #endif
 
@@ -97,7 +100,6 @@ void infill();
 void velblock();
 
 /*##################################################################*/
-
 void DAVG2TAVG(vavg,depth,nd,time)
 float *vavg,*depth,*time;
 int *nd;
