@@ -27,11 +27,18 @@
  */
 
 #include <stdio.h>
+#include <stdlib.h>
+#include <unistd.h>
+#ifdef USE_SYS_MALLOC
+#include <sys/malloc.h>
+#else
+#include <malloc.h>
+#endif
 #include <curses.h>
 #include <fcntl.h>
 #include <signal.h>
 #include <string.h>
-#include <errno.h>
+#include <sys/errno.h>
 
 #include <localsys.h>
 
@@ -43,6 +50,8 @@
 #define XCENTER(x) (((LINES - x - 1) / 2) >= 0 ? (LINES - x - 1) / 2 : 0)
 #define YCENTER(x) (((COLS - x - 1) / 2) >= 0 ? (COLS - x - 1) / 2 : 0)
 
+extern int errno;
+
 #ifdef DEBUG
 FILE *db;
 #endif
@@ -156,7 +165,11 @@ char *argv[];
 	signal(SIGALRM,docmd);
 	docmd();
 
+#ifdef MACOSXSYSTEM
+	if (fcntl(fileno(stdin),F_SETFL,O_ASYNC) == -1) {
+#else
 	if (fcntl(fileno(stdin),F_SETFL,O_SYNC) == -1) {
+#endif
 	  perror("cmdwatch");
 	  exit(1);
 	  }
