@@ -128,7 +128,11 @@ char *filename;
 
 
 #include <stdarg.h>
+#ifdef USE_SYS_MALLOC
+#include <sys/malloc.h>
+#else
 #include <malloc.h>
+#endif
 #define new_node(type)    ((type *) malloc( sizeof( type ) ))
 typedef struct linklist {
    char              *s;
