@@ -38,7 +38,7 @@ Connector *cnt_create(Process *p,
   
   if (p == (Process *) NULL) {
     ikp_err("Connector not bound to process.", NONFATAL);
-    cfree(new);
+    free(new);
     return((Connector *) NULL);
   }
   new->cnt_process= (caddr_t) p;
@@ -47,21 +47,21 @@ Connector *cnt_create(Process *p,
     for (c= p->prc_input; c != (Connector *) NULL; c= c->cnt_next) {
       if (fd == c->cnt_desc) {
 	ikp_err("Duplicate input connector descriptor.", NONFATAL);
-	cfree(new);
+	free(new);
 	return((Connector *) NULL);
       }
     }
     for (c= p->prc_output; c != (Connector *) NULL; c= c->cnt_next) {
       if (fd == c->cnt_desc) {
 	ikp_err("Duplicate output connector descriptor.", NONFATAL);
-	cfree(new);
+	free(new);
 	return((Connector *) NULL);
       }
     }
     for (c= p->prc_diag; c != (Connector *) NULL; c= c->cnt_next) {
       if (fd == c->cnt_desc) {
 	ikp_err("Duplicate diagnostic connector descriptor.", NONFATAL);
-	cfree(new);
+	free(new);
 	return((Connector *) NULL);
       }
     }
@@ -72,21 +72,21 @@ Connector *cnt_create(Process *p,
     for (c= p->prc_input; c != (Connector *) NULL; c= c->cnt_next) {
       if (fd == c->cnt_desc) {
 	ikp_err("Duplicate input connector descriptor.", NONFATAL);
-	cfree(new);
+	free(new);
 	return((Connector *) NULL);
       }
     }
     for (c= p->prc_output; c != (Connector *) NULL; c= c->cnt_next) {
       if (fd == c->cnt_desc) {
 	ikp_err("Duplicate output connector descriptor.", NONFATAL);
-	cfree(new);
+	free(new);
 	return((Connector *) NULL);
       }
     }
     for (c= p->prc_diag; c != (Connector *) NULL; c= c->cnt_next) {
       if (fd == c->cnt_desc) {
 	ikp_err("Duplicate diagnostic connector descriptor.", NONFATAL);
-	cfree(new);
+	free(new);
 	return((Connector *) NULL);
       }
     }
@@ -97,21 +97,21 @@ Connector *cnt_create(Process *p,
     for (c= p->prc_input; c != (Connector *) NULL; c= c->cnt_next) {
       if (fd == c->cnt_desc) {
 	ikp_err("Duplicate input connector descriptor.", NONFATAL);
-	cfree(new);
+	free(new);
 	return((Connector *) NULL);
       }
     }
     for (c= p->prc_output; c != (Connector *) NULL; c= c->cnt_next) {
       if (fd == c->cnt_desc) {
 	ikp_err("Duplicate output connector descriptor.", NONFATAL);
-	cfree(new);
+	free(new);
 	return((Connector *) NULL);
       }
     }
     for (c= p->prc_diag; c != (Connector *) NULL; c= c->cnt_next) {
       if (fd == c->cnt_desc) {
 	ikp_err("Duplicate diagnostic connector descriptor.", NONFATAL);
-	cfree(new);
+	free(new);
 				return((Connector *) NULL);
       }
     }
@@ -120,7 +120,7 @@ Connector *cnt_create(Process *p,
     break;
   default:
     ikp_err("Invalid connector type.", NONFATAL);
-    cfree(new);
+    free(new);
     return((Connector *) NULL);
   }
   new->cnt_iodir= iodir;
@@ -262,7 +262,7 @@ cnt_ground(Connector *c)
   if (net_op == CNT_GRNDNULL) {
     cnt_drawgrnd(p, c);
     if (c->cnt_filename != (char *) NULL)
-      cfree(c->cnt_filename);
+      free(c->cnt_filename);
     if ((c->cnt_filename= calloc((unsigned) (strlen("/dev/null")+1), sizeof(char))) == (char *) NULL)
       ikp_err("Memory allocation error.", FATAL);
     (void) strcpy(c->cnt_filename, "/dev/null");
@@ -293,7 +293,7 @@ cnt_unlink(Connector *c)
     seg_erasepath(c);
   for (s= c->cnt_seglist; s != (Segment *) NULL; s= t) {
     t= s->seg_next;
-    cfree((char *) s);
+    free((char *) s);
   }
   if (c->cnt_conn != (Connector *) NULL) {
     c->cnt_conn->cnt_conn= (Connector *) NULL;
@@ -302,7 +302,7 @@ cnt_unlink(Connector *c)
   c->cnt_conn= (Connector *) NULL;
   c->cnt_seglist= (Segment *) NULL;
   if (c->cnt_filename != (char *) NULL) {
-    cfree(c->cnt_filename);
+    free(c->cnt_filename);
     c->cnt_filename= (char *) NULL;
   }
   c->cnt_flags&= ~CNT_FILE;
