@@ -307,7 +307,7 @@ int net_fork(Net *nt)
   
   /* allocate pipeslots */
   if (nt->net_pst != (Pipeslot *) NULL)
-    cfree((char *) nt->net_pst);
+    free((char *) nt->net_pst);
   nt->net_npipes= getdtablesize()-RESERVED_FDS-rem_procs;
   nt->net_pst= pst_allocblk(nt->net_npipes);
   
