@@ -339,7 +339,7 @@ int net_readprc(int x,int y,Net *nt,FILE *fp)
 	return(IKP_FAILURE);
       }
       if (p->prc_host != (char *) NULL) {
-	cfree(p->prc_host);
+	free(p->prc_host);
 	p->prc_host= (char *) NULL;
       }
       if (strlen(token) > 0) {
@@ -356,7 +356,7 @@ int net_readprc(int x,int y,Net *nt,FILE *fp)
 	return(IKP_FAILURE);
       }
       if (p->prc_user != (char *) NULL) {
-	cfree(p->prc_user);
+	free(p->prc_user);
 	p->prc_user= (char *) NULL;
       }
       if (strlen(token) > 0) {
@@ -373,7 +373,7 @@ int net_readprc(int x,int y,Net *nt,FILE *fp)
 	return(IKP_FAILURE);
       }
       if (p->prc_comm != (char *) NULL) {
-	cfree(p->prc_comm);
+	free(p->prc_comm);
 	p->prc_comm= (char *) NULL;
       }
       if (strlen(token) > 0) {
@@ -390,7 +390,7 @@ int net_readprc(int x,int y,Net *nt,FILE *fp)
 	return(IKP_FAILURE);
       }
       if (p->prc_dir != (char *) NULL) {
-	cfree(p->prc_dir);
+	free(p->prc_dir);
 	p->prc_dir= (char *) NULL;
       }
       if (strlen(token) > 0) {
@@ -407,7 +407,7 @@ int net_readprc(int x,int y,Net *nt,FILE *fp)
 	return(IKP_FAILURE);
       }
       if (p->prc_label != (char *) NULL) {
-	cfree(p->prc_label);
+	free(p->prc_label);
 	p->prc_label= (char *) NULL;
       }
       if (strlen(token) > 0) {
@@ -424,7 +424,7 @@ int net_readprc(int x,int y,Net *nt,FILE *fp)
 	return(IKP_FAILURE);
       }
       if (p->prc_imagefile != (char *) NULL) {
-	cfree(p->prc_imagefile);
+	free(p->prc_imagefile);
 	p->prc_imagefile= (char *) NULL;
       }
       if (strlen(token) > 0) {
@@ -564,7 +564,7 @@ int net_readprc(int x,int y,Net *nt,FILE *fp)
 	if (p->prc_module!=NULL) {
 	  p->prc_module->mdl_path=strdup(path_name);
 	  if (p->prc_module->mdl_dir != (char *) NULL) {
-	    cfree(p->prc_module->mdl_dir);
+	    free(p->prc_module->mdl_dir);
 	    p->prc_module->mdl_dir=NULL;
 	  }
 	  if (p->prc_dir!=NULL)
