@@ -11,7 +11,7 @@
  *					- j.m.wade - 92083
  */
 /*
-	changed all calls to cfree() to free() calls. The damn convex
+	changed all calls to free() to free() calls. The damn convex
 	had a different syntax than the rest of the free world.
 					- j.m.wade - 1/19/96
 */
