@@ -42,6 +42,6 @@ int wtp_delete(int pid)
     for (x= waitlist; x->wtp_next != w; x= x->wtp_next);
     x->wtp_next= w->wtp_next;
   }
-  cfree((char *) w);
+  free((char *) w);
   return(IKP_SUCCESS);
 }
