@@ -77,6 +77,9 @@ char *arch= "IRIX64";
 #ifdef __i686__ 
 char *arch= "i686";
 #endif
+#ifdef __ppc__		/* Macintosh PowerPC running OS X */
+char *arch= "ppc";
+#endif
 char home[MAXFILENMSZ+1];
 
 main(argc, argv)
