@@ -377,7 +377,7 @@ ikpd_dir()
 		  (void) fprintf(errfp, "CURRENT DIR '%s'\n", dir);
 		  }
 		}
-	cfree(dir);
+	free(dir);
 
 	ikpd_success();
 	return;
@@ -500,7 +500,7 @@ ikpd_adjarch()
 				ikpd_failure(IKP_MEMALLOC);
 			(void) strcpy(newev, "ARCH=");
 			(void) strcat(newev, arch);
-			cfree(*ev);
+			free(*ev);
 			*ev= newev;
 			arch_set= TRUE;
 		}
@@ -516,7 +516,7 @@ ikpd_adjarch()
 					(void) strcat(newev, arch);
 					(void) strcat(newev, d);
 					c= (char *) (newev+(c-(*ev))+replen);
-					cfree(*ev);
+					free(*ev);
 					*ev= newev;
 				}
 				else
@@ -557,7 +557,7 @@ ikpd_adjhome()
 				ikpd_failure(IKP_MEMALLOC);
 			(void) strcpy(newev, "HOME=");
 			(void) strcat(newev, home);
-			cfree(*ev);
+			free(*ev);
 			*ev= newev;
 			home_set= TRUE;
 		}
@@ -573,7 +573,7 @@ ikpd_adjhome()
 					(void) strcat(newev, home);
 					(void) strcat(newev, d);
 					c= (char *) (newev+(c-(*ev))+replen);
-					cfree(*ev);
+					free(*ev);
 					*ev= newev;
 				}
 				else
@@ -628,13 +628,13 @@ ikpd_adjpath()
 
 	/* reset old PATH to new, if found */
 	if (*pathev != (char *) NULL) {
-		cfree(*pathev);
+		free(*pathev);
 		*pathev= newpath;
 	}
 
 	/* if not, store PATH in IKPRPATH slot */
 	else {
-		cfree(*ikppathev);
+		free(*ikppathev);
 		*ikppathev= newpath;
 	}
 
