@@ -41,7 +41,7 @@
  
 int qestf_(int *winLength, int *freqNum, int *fitDataNum, int *dataLength, 
 		double *dt, int *nfs, double *data, double *output, double *peakf,
-		double *peaka, double *xReal, double *xImag, double *xAbs, double *x1, double *cut , double *df)
+		double *peaka, double *xReal, double *xImag, double *xAbs, double *x1, double *cut , double *df, int *nfst)
 {
   int linearInt(int, int, double *);
   double peakFit(int, double *);
@@ -61,6 +61,7 @@ int qestf_(int *winLength, int *freqNum, int *fitDataNum, int *dataLength,
   double last_peakf;
   int N = *nfs;
   int NF;
+  int nf1 = *nfst;
 
 /*  I am commenting this next part out and allocating memory in
     the main as we are getting a segmentation fault here and I
@@ -99,15 +100,25 @@ int qestf_(int *winLength, int *freqNum, int *fitDataNum, int *dataLength,
   /* Find the value and the location of the maximum */
 
   for (i=0; i<=*dataLength-*winLength;i++) {       
-      maxValue=0.0;
-      freqMax=0;
-      for (j=0;j<N;j++)
-      {   if (maxValue <= xAbs[j])
+      if (nf1 > 0) 
+      {
+          maxValue=xAbs[nf1];
+          freqMax=nf1;
+          peakf[i] = freqMax;
+          peaka[i] = sqrt (maxValue);
+      }
+      else 
+      {
+        maxValue=0.0;
+        freqMax=0;
+        for (j=0;j<N;j++)
+        {   if (maxValue <= xAbs[j])
           {  maxValue=xAbs[j];
              freqMax=j;
 	     peakf[i] = freqMax;
              peaka[i] = sqrt (maxValue);
           }
+        }
       }
 
 /* if ( i%100 == 0 ) {
