@@ -39,7 +39,7 @@
  *	)			 
  */ 
  
-int qestf1_(int *winLength,int *freqNum,int *fitDataNum,int *dataLength,double *dt,int *nfs,double *data,double *output,double *peakf,double *peaka,double *xReal,double *xImag,double *xAbs,double *x1,double *cut, double *df )
+int qestf1_(int *winLength,int *freqNum,int *fitDataNum,int *dataLength,double *dt,int *nfs,double *data,double *output,double *peakf,double *peaka,double *xReal,double *xImag,double *xAbs,double *x1,double *cut, double *df, int *nfst )
 {
   double slopeFit(int, double *);
   int adaptDFT(int, int, int, double, double, double *,double *, double *);
@@ -59,6 +59,7 @@ int qestf1_(int *winLength,int *freqNum,int *fitDataNum,int *dataLength,double *
   double last_peakf;
   int N = *nfs;
   int NF= *fitDataNum;
+  int nf1 = *nfst;
 
 /*  I am commenting this next part out and allocating memory in
     the main as we are getting a segmentation fault here and I
@@ -104,15 +105,25 @@ int qestf1_(int *winLength,int *freqNum,int *fitDataNum,int *dataLength,double *
   /* Find the value and the location of the maximum */
 
   for (i=0; i<=*dataLength-*winLength;i++) {       
-      maxValue=0.0;
-      freqMax=0;
-      for (j=0;j<N;j++)
-      {   if (maxValue <= xAbs[j])
+      if (nf1 > 0) 
+      {
+          maxValue=xAbs[nf1];
+          freqMax=nf1;
+          peakf[i] = freqMax;
+          peaka[i] = sqrt (maxValue);
+      }
+      else
+      {
+        maxValue=0.0;
+        freqMax=0;
+        for (j=0;j<N;j++)
+        {   if (maxValue <= xAbs[j])
           {  maxValue=xAbs[j];
              freqMax=j;
 	     peakf[i] = freqMax;
 	     peaka[i] = sqrt (maxValue);
           }
+        }
       }
 
 /*
