@@ -36,7 +36,7 @@ timation.
  *      )
  */
 
-int qestm_(int *winLength,int *freqNum,int *fitDataNum,int *dataLength,int *order,int *delay,double *dt,int *nfs,double *data,double *output,double *peakf,double *peaka,double *cut, double *df)
+int qestm_(int *winLength,int *freqNum,int *fitDataNum,int *dataLength,int *order,int *delay,double *dt,int *nfs,double *data,double *output,double *peakf,double *peaka,double *cut, double *df, int *nfst)
 {
     int linearInt(int, int, double *);
     double peakFit(int, double *);
@@ -51,6 +51,7 @@ int qestm_(int *winLength,int *freqNum,int *fitDataNum,int *dataLength,int *orde
     double ave;
     int N = *nfs;
     int NF= *fitDataNum;
+    int nf1 = *nfst;
     double b, sum, rho, maxValue;
     double *r, *aNew, *aOld, *xReal, *xImag, *spectrum, *x1;
     double last_slope;
@@ -138,16 +139,26 @@ if ( n > 1 && n < 12 ){
  }
 }
 */
+        if (nf1 > 0) 
+        {
+          maxValue=spectrum[nf1];
+          freqMax=nf1;
+          peakf[n] = freqMax;
+          peaka[n] = sqrt (maxValue);
+        }
+        else
+        {
         /* Find the value and the location of the peak */
-        maxValue=0.0;
-        freqMax=0;
-        for (j=0;j<N;j++)
-        {   if (maxValue <= spectrum[j])
+          maxValue=0.0;
+          freqMax=0;
+          for (j=0;j<N;j++)
+          {   if (maxValue <= spectrum[j])
             {  maxValue=spectrum[j];
                freqMax=j;
                peakf[n]=freqMax;
                peaka[n] = sqrt (maxValue);
             }
+          }
         }
 
         for (j=freqMax+mdelay;j<=N;j++)
