@@ -5,6 +5,8 @@
  ***********************************************************************/
 #include <stdio.h>
 #include <stdlib.h>
+#include <sys/types.h>
+#include <unistd.h>
 #include <localsys.h>
 #include <save.h>
 #include <io_defs.h>
@@ -13,6 +15,7 @@
 #include <header.h>
 #include <errno.h>
 #include <string.h>
+#include <time.h>
 
 int verbose;
 FILE *prtfile;
@@ -41,6 +44,7 @@ char **argv;
 	short  numaux, cdpfold, origsmpint, orignumsmp;
 	int line_hdr_indx,trace_hdr_indx;
 	int indx,bytes,help,databytes,segydatabytes;
+	int date_conv();
 #if ( BYTE_ORDER == LITTLE_ENDIAN )
 	char native[8];
 	int native_line_header, native_trace_header, native_trace_data;
@@ -55,6 +59,14 @@ char **argv;
 	int lval;
 	float rval;
 	char *chval;
+	int DateYear_format, DateYear_index, DateYear_length;
+	int DateDay_format, DateDay_index, DateDay_length;
+	int DateHour_format, DateHour_index, DateHour_length;
+	int DateMin_format, DateMin_index, DateMin_length;
+	int DateSec_format, DateSec_index, DateSec_length;
+	int DateType_format, DateType_index, DateType_length;
+	int SGRDat_format, SGRDat_index, SGRDat_length;
+	int SGRAmp_format, SGRAmp_index, SGRAmp_length;
 	int TrcNumSmp_format, TrcNumSmp_index, TrcNumSmp_length;
 	int TrcIdCode_format, TrcIdCode_index, TrcIdCode_length;
 	int FieldRecNum_format, FieldRecNum_index, FieldRecNum_length;
@@ -84,7 +96,13 @@ char **argv;
 	int hlhknt,hlh_byte_total;
 	char *hlh[40]; /* this is limited to 40 lines in the SEGY data */
 	short hlh_entry_length;
+	time_t timeval;
+	struct tm timestruct;
+	short datetype,year,yday,hour,minute,second;
+
 	int read_map_file();
+	void HTOCL(),HTOCS(),F_EBCASC(),ibm_to_float();
+	char *cgdate();
 
 	help = C_ARGIS("-?",&argc,argv);
 	help += C_ARGIS("-h",&argc,argv);
@@ -616,7 +634,7 @@ if (errno != 0) {fprintf(stderr,"errno = %d\n",errno); perror("Invalid"); }
 	  }
 
 /* I got lazy here and just assumed a max HLH of 3200 - that's the SEGY max 
-   and we're substituting two bytes lenght entries for the 'C ##' characters
+   and we're substituting two bytes length entries for the 'C ##' characters
    on the SEGY entries
 */
 	if ((header = (char *)malloc(HSTOFF+3200)) == NULL) {
@@ -682,7 +700,7 @@ if (errno != 0) {fprintf(stderr,"errno = %d\n",errno); perror("Invalid"); }
 #if ( BYTE_ORDER == LITTLE_ENDIAN )
 	            if (strncmp(segy_line_hdr_map[indx].tag,"Spare",5) == 0) {
 			HTOCS(buffer+
-			  (segy_line_hdr_map[indx].index*sizeof(int)),
+			  (segy_line_hdr_map[indx].index*sizeof(short)),
 			  segy_line_hdr_map[indx].length);
 			}
 #endif
@@ -760,6 +778,7 @@ if (errno != 0) {fprintf(stderr,"errno = %d\n",errno); perror("Invalid"); }
 	  memcpy(bufptr,hlh[i],hlh_entry_length);
 	  bufptr+=hlh_entry_length;
 	  }
+
 	put_hw_val(header,"PrcDat",LINEHEADER,cgdate());
 	put_hw_val(header,"HlhEnt",LINEHEADER,hlhknt);
 	put_hw_val(header,"HlhByt",LINEHEADER,hlh_byte_total);
@@ -785,6 +804,10 @@ if (errno != 0) {fprintf(stderr,"errno = %d\n",errno); perror("Invalid"); }
 		segydatabytes = numsmp * sizeof(short);
 		databytes = numsmp * SZSMPD;
 		break;
+	  case(5):
+		segydatabytes = numsmp * sizeof(float);
+		databytes = numsmp * SZSMPD;
+		break;
 	  default:
 		fprintf(stderr,"SEGY2USP ERROR: no method for converting SEGY data with format code %d\n",fmtcode);
 		exit(1);
@@ -850,6 +873,26 @@ if (errno != 0) {fprintf(stderr,"errno = %d\n",errno); perror("Invalid"); }
 			&TrcNumSmp_length, SEGYTRACEHEADER);
 	  }
 
+/*
+ * These are used in retrieving the SEGY trace recording times
+ */
+	C_SAVELU("DateYear", &DateYear_format, &DateYear_index,
+			&DateYear_length, SEGYTRACEHEADER);
+	C_SAVELU("DateDay", &DateDay_format, &DateDay_index,
+			&DateDay_length, SEGYTRACEHEADER);
+	C_SAVELU("DateHour", &DateHour_format, &DateHour_index,
+			&DateHour_length, SEGYTRACEHEADER);
+	C_SAVELU("DateMin", &DateMin_format, &DateMin_index,
+			&DateMin_length, SEGYTRACEHEADER);
+	C_SAVELU("DateSec", &DateSec_format, &DateSec_index,
+			&DateSec_length, SEGYTRACEHEADER);
+	C_SAVELU("DateType", &DateType_format, &DateType_index,
+			&DateType_length, SEGYTRACEHEADER);
+	C_SAVELU("SGRDat", &SGRDat_format, &SGRDat_index,
+			&SGRDat_length, TRACEHEADER);
+	C_SAVELU("SGRAmp", &SGRAmp_format, &SGRAmp_index,
+			&SGRAmp_length, TRACEHEADER);
+
 	trcknt = 0;
 
 	while (1) {
@@ -880,6 +923,37 @@ if (errno != 0) {fprintf(stderr,"errno = %d\n",errno); perror("Invalid"); }
 	    HTOCS(buffer+(index*sizeof(short)),46);
 	    }
 #endif
+
+/* This code takes the SEGY trace date stamp and stuffs it into
+ * a time_t value with a mask corresponding to the date type.
+ */
+	memset(&timestruct,0,sizeof(struct tm));
+	timestruct.tm_isdst = -1;
+	get_indexed_hw_val(buffer,DateYear_format,DateYear_index,
+		DateYear_length,SEGYTRACEHEADER,&year);
+	timestruct.tm_year = year;
+	if (timestruct.tm_year >= 1900) timestruct.tm_year -= 1900;
+	get_indexed_hw_val(buffer,DateDay_format,DateDay_index,
+		DateDay_length,SEGYTRACEHEADER,&yday);
+	timestruct.tm_yday = yday;
+	get_indexed_hw_val(buffer,DateHour_format,DateHour_index,
+		DateHour_length,SEGYTRACEHEADER,&hour);
+	timestruct.tm_hour = hour;
+	get_indexed_hw_val(buffer,DateMin_format,DateMin_index,
+		DateMin_length,SEGYTRACEHEADER,&minute);
+	timestruct.tm_min = minute;
+	get_indexed_hw_val(buffer,DateSec_format,DateSec_index,
+		DateSec_length,SEGYTRACEHEADER,&second);
+	timestruct.tm_sec = second;
+	get_indexed_hw_val(buffer,DateType_format,DateType_index,
+		DateType_length,SEGYTRACEHEADER,&datetype);
+	date_conv(&timestruct);
+	timeval = mktime(&timestruct);
+
+	put_indexed_hw_val(header,SGRDat_format,SGRDat_index,
+		SGRDat_length,TRACEHEADER,timeval);
+	put_indexed_hw_val(header,SGRAmp_format,SGRAmp_index,
+		SGRAmp_length,TRACEHEADER,datetype);
 /*
    Take care of the specified trace header mappings
 */
@@ -915,7 +989,7 @@ if (errno != 0) {fprintf(stderr,"errno = %d\n",errno); perror("Invalid"); }
 #if ( BYTE_ORDER == LITTLE_ENDIAN )
 	            if (strncmp(segy_trace_hdr_map[indx].tag,"Spare",5) == 0) {
 			HTOCS(buffer+
-			  (segy_trace_hdr_map[indx].index*sizeof(int)),
+			  (segy_trace_hdr_map[indx].index*sizeof(short)),
 			  segy_trace_hdr_map[indx].length);
 			}
 #endif
@@ -978,6 +1052,7 @@ if (errno != 0) {fprintf(stderr,"errno = %d\n",errno); perror("Invalid"); }
                             TRACEHEADER,rval);
 		  break;
 		  }
+/* for (j=30; j<34; j++) fprintf(stderr,"map index %d: %d %08x \n",indx,j,*(long *)(buffer+SEGYTRACEHEADERBYTES+(j*sizeof(float)))); */
 		}
 
 	  if (verbose >= 2) {
@@ -1042,9 +1117,17 @@ if (errno != 0) {fprintf(stderr,"errno = %d\n",errno); perror("Invalid"); }
 		  if (native_trace_data != 1) HTOCL(header+SZTRHD,numsmp);
 #endif
 		  break;
+		case(5):
+	    	  for (j=0; j<numsmp; j++) {
+			*(float *)(header + SZTRHD + (j*SZSMPD)) = (float)
+			  (*(float *)(buffer+SEGYTRACEHEADERBYTES+
+				(j*sizeof(float))));
+			}
+#if ( BYTE_ORDER == LITTLE_ENDIAN )
+		  if (native_trace_data != 1) HTOCL(header+SZTRHD,numsmp);
+#endif
+	          break;
 		}
-		  
-
 	
 	  C_WRTAPE(luout,header,SZTRHD+databytes);
 	  }
@@ -1101,3 +1184,37 @@ int indx;
 	  fprintf(prtfile," number of items in %s = %d\n",map_file,indx);
 	return(indx);
 }
+int date_conv(time_struct)
+struct tm *time_struct;
+{ 
+	int i;
+	int normal_months[] = { 31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31 };
+	int leap_months[] = { 31, 29, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31 };
+	int yday,day,month,year;
+	int *months,leap,leapchk();
+	year = time_struct->tm_year + 1900;	
+/*	leap = leapchk(year); */
+	leap = (year % 4 == 0 && (year % 100 != 0 || year % 400 == 0));
+	if (leap != 0)
+	  months = leap_months;
+	else
+	  months = normal_months;
+	yday = time_struct->tm_yday;
+	for (month=0; month<12, yday>0; month++) {
+	  day = yday;
+	  yday -= months[month];
+	  if (yday <= 0) {
+	    time_struct->tm_mon = month;
+	    time_struct->tm_mday = day;
+	    }
+	  }
+	month = time_struct->tm_mon + 1;
+	day = time_struct->tm_mday;
+}
+/*
+int leapchk(year)
+int year;
+{
+	return (year % 4 == 0 && (year % 100 != 0 || year % 400 == 0));
+}
+*/
