@@ -1,7 +1,11 @@
 #include <stdio.h>
 #include <string.h>
-#ifndef __convex__
+#ifdef USE_SYS_MALLOC
+#include <sys/malloc.h>
+#else
 #include <malloc.h>
+#endif
+#ifndef __convex__
 #include <memory.h>
 #endif
 
