@@ -5,6 +5,12 @@
  ***********************************************************************/
 #include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
+#ifdef USE_SYS_MALLOC
+#include <sys/malloc.h>
+#else
+#include <malloc.h>
+#endif
 #include <localsys.h>
 #include <save.h>
 #include <io_defs.h>
@@ -13,6 +19,9 @@
 #include <header.h>
 #include <errno.h>
 #include <strings.h>
+#include <time.h>
+#include <sys/types.h>
+#include <unistd.h>
 
 int verbose;
 FILE *prtfile;
@@ -75,6 +84,14 @@ char **argv;
 	int TrcSmpInt_format, TrcSmpInt_index, TrcSmpInt_length;
 	int CdpNum_format, CdpNum_index, CdpNum_length;
 	int CdpTrcNum_format, CdpTrcNum_index, CdpTrcNum_length;
+	int DateYear_format, DateYear_index, DateYear_length;
+	int DateDay_format, DateDay_index, DateDay_length;
+	int DateHour_format, DateHour_index, DateHour_length;
+	int DateMin_format, DateMin_index, DateMin_length;
+	int DateSec_format, DateSec_index, DateSec_length;
+	int DateType_format, DateType_index, DateType_length;
+	int SGRAmp_format, SGRAmp_index, SGRAmp_length;
+	int SGRDat_format, SGRDat_index, SGRDat_length;
 	typedef struct {
 		char *tag;
 		int hdrtype;
@@ -86,6 +103,12 @@ char **argv;
 	save_struct *hdr_map,*line_hdr_map,*trace_hdr_map;
 	save_struct **segy_line_hdr_map,**segy_trace_hdr_map;
 
+	void HTOCL(),HTOCS();
+        void F_ASCEBC(), float_to_ibm();
+        int gethlh();
+
+
+
 	short fmtcode,unitsflg;
 	char jobnum[8];
 	int linetrcnum;
@@ -94,6 +117,11 @@ char **argv;
 	int cdpnum, cdptrcnum;
 	int hlhknt;
 	char **hlh;
+	time_t timeval;
+	struct tm timestruct;
+	short datetype;
+	short year,yday,hour,minute,second;
+
 	int read_map_file();
 
 	help = C_ARGIS("-?",&argc,argv);
@@ -328,11 +356,14 @@ need to check return codes ; we should also realloc after looking up indices
 	  fprintf(prtfile,"job identification number        = ");
 	  for (i=0; i<8; i++) {fprintf(prtfile,"%c",jobnum[i]);}
 	  fprintf(prtfile,"\n");
-	  fprintf(prtfile,"data traces per record           = %ld\n",numtrc);
-	  fprintf(prtfile,"sample interval in ms. = %ld\n",smpint);
+	  fprintf(prtfile,"data traces per record           = %ld\n",
+		(long) numtrc);
+	  fprintf(prtfile,"sample interval in ms. = %ld\n",
+		(long) smpint);
 	  fprintf(prtfile,"unit scaler value = %f\n",unitscaler);
 	  fprintf(prtfile,"sample interval in seconds = %f\n",smpint*unitscaler);
-	  fprintf(prtfile,"samples/trace                    = %ld\n",numsmp);
+	  fprintf(prtfile,"samples/trace                    = %ld\n",
+		(long) numsmp);
 	  fprintf(prtfile,"data sample format code          = %d\n",fmtcode);
 	  fprintf(prtfile,"CDP fold                         = %d\n",cdpfold);
 	  fprintf(prtfile,"units flag = %d\n",unitsflg);
@@ -756,6 +787,11 @@ need to check return codes ; we should also realloc after looking up indices
 		&PrRcNm_length, TRACEHEADER);
 	C_SAVELU("PrTrNm", &PrTrNm_format, &PrTrNm_index,
 		&PrTrNm_length, TRACEHEADER);
+	C_SAVELU("SGRDat", &SGRDat_format, &SGRDat_index,
+		&SGRDat_length, TRACEHEADER);
+	C_SAVELU("SGRAmp", &SGRAmp_format, &SGRAmp_index,
+		&SGRAmp_length, TRACEHEADER);
+
 	C_SAVELU("SrcDepth", &SrcDepth_format, &SrcDepth_index,
 			&SrcDepth_length, SEGYTRACEHEADER);
 	C_SAVELU("FieldRecNum", &FieldRecNum_format, &FieldRecNum_index,
@@ -770,6 +806,18 @@ need to check return codes ; we should also realloc after looking up indices
 			&CdpNum_length, SEGYTRACEHEADER);
 	C_SAVELU("CdpTrcNum", &CdpTrcNum_format, &CdpTrcNum_index,
 			&CdpTrcNum_length, SEGYTRACEHEADER);
+	C_SAVELU("DateYear", &DateYear_format, &DateYear_index,
+			&DateYear_length, SEGYTRACEHEADER);
+	C_SAVELU("DateDay", &DateDay_format, &DateDay_index,
+			&DateDay_length, SEGYTRACEHEADER);
+	C_SAVELU("DateHour", &DateHour_format, &DateHour_index,
+			&DateHour_length, SEGYTRACEHEADER);
+	C_SAVELU("DateMin", &DateMin_format, &DateMin_index,
+			&DateMin_length, SEGYTRACEHEADER);
+	C_SAVELU("DateSec", &DateSec_format, &DateSec_index,
+			&DateSec_length, SEGYTRACEHEADER);
+	C_SAVELU("DateType", &DateType_format, &DateType_index,
+			&DateType_length, SEGYTRACEHEADER);
 /*
    Set TrcNumSmp and TrcSmpInt to USP line header values as default
 */
@@ -796,6 +844,33 @@ need to check return codes ; we should also realloc after looking up indices
 	  put_indexed_hw_val(header, LineTrcNum_format, LineTrcNum_index,
 		LineTrcNum_length, SEGYTRACEHEADER, linetrcnum);
 */
+/* 
+ * Transform the date back into SEGY form and stuff it in the header
+ */
+	memset(&timestruct,0,sizeof(struct tm));
+	get_indexed_hw_val(buffer,SGRAmp_format,SGRAmp_index,
+		SGRAmp_length,TRACEHEADER,&datetype);
+	get_indexed_hw_val(buffer,SGRDat_format,SGRDat_index,
+		SGRDat_length,TRACEHEADER,&timeval);
+
+	localtime_r(&timeval,&timestruct );
+	year = timestruct.tm_year+1900;
+	yday = timestruct.tm_yday + 1;
+	hour = timestruct.tm_hour;
+	minute = timestruct.tm_min;
+	second = timestruct.tm_sec;
+	put_indexed_hw_val(header,DateYear_format,DateYear_index,
+		DateYear_length,SEGYTRACEHEADER,year);
+	put_indexed_hw_val(header,DateDay_format,DateDay_index,
+		DateDay_length,SEGYTRACEHEADER,yday);
+	put_indexed_hw_val(header,DateHour_format,DateHour_index,
+		DateHour_length,SEGYTRACEHEADER,hour);
+	put_indexed_hw_val(header,DateMin_format,DateMin_index,
+		DateMin_length,SEGYTRACEHEADER,minute);
+	put_indexed_hw_val(header,DateSec_format,DateSec_index,
+		DateSec_length,SEGYTRACEHEADER,second);
+	put_indexed_hw_val(header,DateType_format,DateType_index,
+		DateType_length,SEGYTRACEHEADER,datetype);
 
 /*
    Take care of the specified trace header mappings
