@@ -1,15 +1,15 @@
-/***********************************************************************
- *                copyright 2001, Amoco Production Company             *
- *                            All Rights Reserved                      *
- *                    an affiliate of BP America Inc.                  *
- ***********************************************************************/
 /* ********************************************************************
+**               AMOCO PRODUCTION COMPANY PROPRIETARY                **
+**                  TO BE MAINTAINED IN CONFIDENCE                   **
+**              COPYRIGHT AMOCO PRODUCTION COMPANY, 1992             **
+**                                                                   **
 **       Program new_draw                                            **
 **     coded by R. Crider and D. Boddy,  APC                         **
 **                                                                   **
 **********************************************************************/
 #include "xos.h"
 #include "globals.h"
+#include <X11/X.h>
 #ifdef SUNSYSTEM
 #include <sys/types.h>
 #include <netinet/in.h>
@@ -207,6 +207,7 @@ draw_it(ierr, sp, toplevel)
 
     static Pixel  white, black;
 
+    int byte_order;
     int dpthrast, quantum, ip;
 /*******************************************************************/
 
@@ -229,6 +230,7 @@ draw_it(ierr, sp, toplevel)
 
     if (first_time) {
 	first_time = 0;
+	byte_order = ImageByteOrder(sp->dpy);
 	font1 = XLoadQueryFont(sp->dpy, "9x15");
 	num_font.width = 9;
 	num_font.height = 15;
@@ -244,27 +246,15 @@ draw_it(ierr, sp, toplevel)
 	     &rgb_db_def, &colorcell);
           color2pixel(&colorcell,visual,depth);
         
+#if ( BYTE_ORDER == LITTLE_ENDIAN )
+		   if (byte_order == LSBFirst) convert = 0;
+		   else convert = 1;
+#endif
+#if ( BYTE_ORDER == BIG_ENDIAN )
+		   if (byte_order == MSBFirst) convert = 0;
+		   else convert = 1;
+#endif
 
-	 if ((depth == 15) || (depth == 16)) {
-#if ( BYTE_ORDER == LITTLE_ENDIAN )
-	 if (visual->red_mask != 0x0000f800) convert = 1;
-	 else convert = 0;
-#endif
-#if ( BYTE_ORDER == BIG_ENDIAN )
-	 if (visual->red_mask != 0x00ff0000) convert = 1;
-	 else convert = 0;
-#endif
-		   }
-	 else if ((depth == 24) || (depth == 32)) {
-#if ( BYTE_ORDER == LITTLE_ENDIAN )
-	  if (visual->red_mask != 0x00ff0000) convert = 1;
-	  else convert = 0;
-#endif
-#if ( BYTE_ORDER == BIG_ENDIAN )
-	  if (visual->red_mask != 0x000000ff) convert = 1;
-	  else convert = 0;
-#endif
-	  }
         }
 
         black = BlackPixel(sp->dpy,DefaultScreen(sp->dpy)); 
