@@ -6,7 +6,7 @@
 #include "xos.h"
 #include "globals.h"
 /*....do not need this---now in xos.h....mam...*/
-#include <malloc.h>
+/* #include <malloc.h> */
 /*..............9-26-94........................*/
 /*
 ** Read an SIS dataset into memory at seisplot structure data pointer
