@@ -18,7 +18,11 @@
 #include <sys/types.h>
 #include <time.h>
 #include <string.h>
+#ifdef USE_SYS_MALLOC
+#include <sys/malloc.h>
+#else
 #include <malloc.h>
+#endif
 #include <stdlib.h>	/* atof */
 #include <unistd.h>	/* R_OK */
 #include <ctype.h>  /* isascii, islower */
