@@ -5,7 +5,12 @@
  ***********************************************************************/
 #include <stdarg.h>
 #include <string.h>
+#include <sys/types.h>
+#ifdef USE_SYS_MALLOC
+#include <sys/malloc.h>
+#else
 #include <malloc.h>
+#endif
 #include <stdio.h>
 #include "std.h"
 
