@@ -63,7 +63,7 @@ void init_defaults(void)
 				/* If hostname is empty set to "=". */
   if (strlen(hostname)==0) strcpy(hostname,"=");
 				/* If username is empty set to cuserid.  */
-  if (strlen(username)==0) strcpy(username,(char*)cuserid(NULL));
+  if (strlen(username)==0) strcpy(username,(char*)getlogin());
 
 				/* Check if ".xsd_define" file exists. */
   if (home) {
