@@ -9,7 +9,11 @@
 */
 
 #include <signal.h>
+#ifdef USE_SYS_MALLOC
+#include <sys/malloc.h>
+#else
 #include <malloc.h>
+#endif
 #ifdef SunOS
 #if defined(sun) && !defined(__SVR4)
 #include <memory.h>	/* memcpy */
