@@ -29,7 +29,9 @@
 #include "mathadv.h"
 #include "usp_headers.h"
 #include "save.h"
-#ifndef __convex__
+#ifdef USE_SYS_MALLOC
+#include <sys/malloc.h>
+#else
 #include <malloc.h>
 #endif
 
