@@ -1,3 +1,9 @@
+#include <stdio.h>
+#include <stdlib.h>
+#include <unistd.h>
+#include <string.h>
+#include <sisio.h>
+
 void vainsah( inbuf, inlen, outbuf, outlen )
 
 	char *	inbuf;
