@@ -5,7 +5,11 @@
  ***********************************************************************/
 #include <stdio.h>
 #include <string.h>
+#ifdef USE_SYS_MALLOC
+#include <sys/malloc.h>
+#else
 #include <malloc.h>
+#endif
 
 #ifdef HPUX
 #define LAUNCH launch
