@@ -3,19 +3,23 @@
  *                            All Rights Reserved                      *
  *                    an affiliate of BP America Inc.                  *
  ***********************************************************************/
+#include <stdio.h>
+#include <string.h>
+#include <sys/types.h>
+#include <sys/stat.h>
 #include <X11/cursorfont.h>
 #include <X11/Intrinsic.h>
 #include <Xm/Xm.h>
 #include <Xm/MessageB.h>
 #include <Xm/FileSB.h>
+#include <Xm/Form.h>
 #include <Xm/Frame.h>
-#include <stdio.h>
-#include <string.h>
-#include <sys/types.h>
-#include <sys/stat.h>
+#include <Xm/PushB.h>
+#include <Xm/SelectioB.h>
+#include <Xm/Text.h>
 
-XtCallbackProc XuNo_More_Help();
-XtCallbackProc XuHelper();
+void XuNo_More_Help();
+void XuHelper();
 void build_message();
 static Widget CreateHelpWindow();
 static Widget text=(Widget)NULL, Help_Window=(Widget)NULL;
@@ -65,7 +69,9 @@ static char *help_mess[] = {
                   ""};   /* note null string terminatior  */
 
 
+/*
 static XmStringCharSet charset = (XmStringCharSet) XmSTRING_DEFAULT_CHARSET;
+*/
 
 
 /*   User calls   */
@@ -126,7 +132,11 @@ char *filename;
 
 
 #include <stdarg.h>
+#ifdef USE_SYS_MALLOC
+#include <sys/malloc.h>
+#else
 #include <malloc.h>
+#endif
 #define new_node(type)    ((type *) malloc( sizeof( type ) ))
 typedef struct linklist {
    char              *s;
@@ -263,14 +273,14 @@ int OpenFile()
    /* read the file string */
    file_string = (unsigned char *) XtMalloc((unsigned)file_length+1);
    fread(file_string, sizeof(char), file_length, fp);
-   file_string[file_length] = NULL;
+   file_string[file_length] = (char) NULL;
 
    /* close up the file */
    if (fclose(fp) != (int)NULL)
 	fprintf(stderr, "Warning: unable to close file.\n");
 
    /* added the file string to the text widget */
-   if(text)XmTextSetString(text, file_string);
+   if(text)XmTextSetString(text, (char *) file_string);
    XtFree((char *)file_string);
     
 
@@ -280,7 +290,7 @@ int OpenFile()
 
 
 
-XtCallbackProc
+void
 Dismiss_Button(w, client, call)
 Widget w;
 caddr_t client;
@@ -294,7 +304,7 @@ caddr_t call;
 
 
 
-XtCallbackProc
+void
 Selection_Dismiss_Button(w, client, call)
 Widget w;
 caddr_t client;
@@ -315,7 +325,7 @@ char  *mess;
 {
     Widget      mess_dialog;
     Arg         args[20];
-    int         argcnt, i;
+    int         argcnt;
     XmString    xmstr[2];
 
     argcnt = 0;
@@ -341,7 +351,7 @@ char  *mess;
 
 
 
-XtCallbackProc
+void
 sel_callback(w, client, call)
 Widget w;
 caddr_t client;
@@ -351,7 +361,6 @@ char *test;
 int i;
 Boolean found;
 
-        XmAnyCallbackStruct *acs=(XmAnyCallbackStruct*)call;
         XmStringGetLtoR (call->value, XmSTRING_DEFAULT_CHARSET, &test);
         Help_Window = (Widget)CreateHelpWindow( Top_Level_Shell );
         filename = concat(help_path,"/",NULL);
@@ -379,7 +388,7 @@ Boolean found;
 
 
 
-XtCallbackProc
+void
 Help_Dismiss(w, client, call)
 Widget w;
 caddr_t client;
@@ -395,7 +404,7 @@ caddr_t call;
 
 
 
-XtCallbackProc
+void
 XuNo_More_Help(w, client, call)
 Widget w;
 caddr_t client;
@@ -417,8 +426,7 @@ Widget parent;
 {
     Arg    	args[12];
     int    	argcnt;
-    Widget 	retval,form,frame;
-    XmString	xmstr[1];
+    Widget 	retval,form;
     Widget	pushButton;
 
     argcnt = 0;
@@ -460,7 +468,7 @@ Widget parent;
 
 
 
-XtCallbackProc
+void
 XuHelp_On_Help(w, client, call)
 Widget w;
 caddr_t client;
@@ -496,7 +504,7 @@ caddr_t call;
 
 
 
-XtCallbackProc
+void
 XuHelp_Index(w, client, call)
 Widget w;
 caddr_t client;
@@ -555,7 +563,7 @@ caddr_t call;
 
 
 
-XtCallbackProc
+void
 XuHelper (w, client, call)
 Widget w;
 caddr_t client;
@@ -594,7 +602,7 @@ unsigned char *helpinfo;
 {
         Help_Window = (Widget)CreateHelpWindow( Top_Level_Shell );
         if(text){
-                 XmTextSetString(text, helpinfo);
+                 XmTextSetString(text,(char *) helpinfo);
                  XtManageChild(Help_Window);
                 }
 }
@@ -602,7 +610,7 @@ unsigned char *helpinfo;
 
 
 
-XtCallbackProc
+void
 XuHelp_On_Context(w, client, call)
 Widget w;
 caddr_t client;
@@ -630,7 +638,7 @@ fprintf(stderr,"Widget selected was %s (%08x)\n",XtName(This_Widget),This_Widget
 
 
 
-XtCallbackProc
+void
 XuHelp_On_Version(w, client, call)
 Widget w;
 caddr_t client;
