@@ -4,8 +4,9 @@
  *                    an affiliate of BP America Inc.                  *
  ***********************************************************************/
 #include <stdio.h>
+#include <stdlib.h>
 
-fatal(token,msg) /* print token, message, then croak */
+void fatal(token,msg) /* print token, message, then croak */
 char *token, *msg;
 {
 	fprintf(stderr,"fatal error ");
