@@ -3,7 +3,11 @@
  *                            All Rights Reserved                      *
  *                    an affiliate of BP America Inc.                  *
  ***********************************************************************/
-waiton(pid) /* get exit status of child pid */
+#include <stdio.h>
+#include <sys/types.h>
+#include <sys/wait.h>
+
+int waiton(pid) /* get exit status of child pid */
 int pid;
 {
 	int code, ret;
