@@ -33,6 +33,14 @@
 			    (see "kill -l") or by signal number. */
 
 #include <stdio.h>
+#include <stdlib.h>
+#include <unistd.h>
+#include <ctype.h>
+#ifdef USE_SYS_MALLOC
+#include <sys/malloc.h>
+#else
+#include <malloc.h>
+#endif
 #include <signal.h>
 #include <string.h>
 #include <fcntl.h>
@@ -236,7 +244,6 @@ static  Arg arg[20];
 static  int ac;
 static  Widget toplevel, form, text, scroll, quit, xselect;
 static  pid_t pid=0;
-static  pid_t grppid=0;
 static  int tee=0, exec=0, concat=0, exitstat=0;
 static  Memory memory;
 static  int argc2;
@@ -258,7 +265,7 @@ static  char *cmdbuf;
    extern void oldfile();
    extern void newfile();
 
-   void xselectCB();
+   static void xselectCB();
 
 /*------------------------------------------------------------*/
 
@@ -272,23 +279,23 @@ main (argc, argv)
 #endif
    extern void execute();
    extern void centermap();
-   extern void adios();
+   static void adios();
    extern char *getclass();
 
 /* XtTimerCallbackProc input(); */
    void input();
-   void kill_input();
-   void sc_toggle();
-   void print_disable();
+   static void kill_input();
+   static void sc_toggle();
+   static void print_disable();
    void catch_signal();
 
+   int siglu();
+
    Pixmap bitmap;
    XmString label,accel_label;
    XtAppContext app_con;
-   XEvent event;
-   Screen  *scrn;
+   /* XEvent event; */
    char *class;
-   char cmd[200];
    Display *dpy;
    unsigned long mask;
    XSetWindowAttributes attr;
@@ -837,7 +844,7 @@ input (clientdata, input_id)
    XtIntervalId	*input_id;
 {
 /* Boolean data_to_be_read(); */
-   void kill_input();
+   static void kill_input();
    void centermap();
    int     bytes_read,knt,knt_bump,ls_bump;
    static short line_number;
@@ -1186,14 +1193,12 @@ void
 execute (cmd)
    char *cmd;
 {
+   extern int errno;
    int std[2], fd, fdlim;
-   char *blankloc;
-   char *cmdptr;
-   char *newcmd;
-   char **cmdargs;
-   int indx;
 
 /*
+    pid_t grppid=0;
+
 	pid = getpid();
 	grppid = getpgrp();
 	fprintf(stderr,"xcat process pid = %d, process group = %d\n",pid,grppid);
@@ -1273,6 +1278,7 @@ print_enable (clientdata, input_id)
    XtIntervalId *input_id;
 {
 	XtSetSensitive((Widget) clientdata,TRUE);
+	return(0);
 }
 
 /*------------------------------------------------------------*/
@@ -1341,7 +1347,6 @@ xselectCB (widget, clientdata, calldata)
     char *insert_pnt,*string_start;
     char *selection;
     static char *cmd;
-    int stat;
     int gray_time = 3000;
     int insertions = 0;
 
@@ -1424,7 +1429,8 @@ kill_input (widget, clientdata, calldata)
    Widget widget;
    XtPointer clientdata, calldata;
 {
-	int code;
+	int waiton();
+	extern int errno;
 	XmString label;
 	Memory  *memory = (Memory *)clientdata;
 
